/*-- Flour --*/

protected func Hit()
{
	Sound("Hits::GeneralHit?");
}

public func IsWindmillProduct() { return true; }

local Name = "$Name$";
local Description = "$Description$";
local Collectible = 1;